@@ -12,7 +12,7 @@ from requests.adapters import HTTPAdapter, Retry
 from Cryptodome.Cipher import AES
 
 from anipy_cli.misc import response_err, error, loc_err, parsenum, Entry
-from anipy_cli.colors import colors
+from anipy_cli.colors import cinput, color, colors
 from anipy_cli.config import Config
 
 
@@ -119,7 +119,7 @@ class epHandler:
         else:
             return ep_list[0]["ep"]
 
-    def _create_prompt(self, prompt="Episode"):
+    def _do_prompt(self, prompt="Episode"):
         ep_range = f" [{self.get_first()}-{self.get_latest()}]"
 
         specials = self.get_special_list()
@@ -127,15 +127,7 @@ class epHandler:
             ep_range += " Special Eps: "
             ep_range += ", ".join([x["ep"] for x in specials])
 
-        return str(
-            colors.END
-            + prompt
-            + colors.GREEN
-            + ep_range
-            + colors.END
-            + "\n>> "
-            + colors.CYAN
-        )
+        return cinput(color(prompt, colors.GREEN, ep_range) + "\n>> ", colors.CYAN)
 
     def _validate_ep(self, ep: str):
         """
@@ -159,7 +151,7 @@ class epHandler:
         self.get_latest()
 
         while True:
-            which_episode = input(self._create_prompt())
+            which_episode = self._do_prompt()
             try:
                 if self._validate_ep(which_episode):
                     self.entry.ep = parsenum(which_episode)
@@ -182,10 +174,8 @@ class epHandler:
         self.get_latest()
 
         while True:
-            which_episode = input(
-                self._create_prompt(
-                    "Last Episode you watched (put 0 to start at the beginning) "
-                )
+            which_episode = self._do_prompt(
+                "Last Episode you watched (put 0 to start at the beginning) "
             )
             try:
                 if self._validate_ep(which_episode) or int(which_episode) == 0:
@@ -214,9 +204,7 @@ class epHandler:
         """
         self.entry.latest_ep = self.get_latest()
         while True:
-            which_episode = input(
-                self._create_prompt(prompt="Episode (Range with '-')")
-            )
+            which_episode = self._do_prompt(prompt="Episode (Range with '-')")
 
             which_episode = which_episode.split("-")
 
@@ -296,10 +284,6 @@ class videourl:
         self.size = AES.block_size
         self.padder = "\x08\x0e\x03\x08\t\x03\x04\t"
         self.pad = lambda s: s + chr(len(s) % 16) * (16 - len(s) % 16)
-        keys = self.get_encryption_keys()
-        self.iv = keys["iv"]
-        self.key = keys["key"]
-        self.second_key = keys["second_key"]
 
     def get_entry(self) -> Entry:
         """
@@ -317,20 +301,30 @@ class videourl:
         self.entry.embed_url = f'https:{link["data-video"]}'
 
     @functools.lru_cache()
-    def get_encryption_keys(self):
+    def get_enc_keys(self):
+        page = self.session.get(self.entry.embed_url).text
+
+        keys = re.findall(r"(?:container|videocontent)-(\d+)", page)
+
+        if not keys:
+            return {}
+
+        key, iv, second_key = keys
+
         return {
-            _: __.encode()
-            for _, __ in self.session.get(self.enc_key_api).json().items()
+            "key": key.encode(),
+            "second_key": second_key.encode(),
+            "iv": iv.encode(),
         }
 
-    def aes_encrypt(self, data, key):
+    def aes_encrypt(self, data, key, iv):
         return base64.b64encode(
-            AES.new(key, self.mode, iv=self.iv).encrypt(self.pad(data).encode())
+            AES.new(key, self.mode, iv=iv).encrypt(self.pad(data).encode())
         )
 
-    def aes_decrypt(self, data, key):
+    def aes_decrypt(self, data, key, iv):
         return (
-            AES.new(key, self.mode, iv=self.iv)
+            AES.new(key, self.mode, iv=iv)
             .decrypt(base64.b64decode(data))
             .strip(b"\x00\x01\x02\x03\x04\x05\x06\x07\x08\t\n\x0b\x0c\r\x0e\x0f\x10")
         )
@@ -350,15 +344,19 @@ class videourl:
         if not self.entry.embed_url:
             self.embed_url()
 
+        enc_keys = self.get_enc_keys()
+
         parsed = urlparse(self.entry.embed_url)
         self.ajax_url = parsed.scheme + "://" + parsed.netloc + self.ajax_url
 
-        data = self.aes_decrypt(self.get_data(), self.key).decode()
+        data = self.aes_decrypt(
+            self.get_data(), enc_keys["key"], enc_keys["iv"]
+        ).decode()
         data = dict(parse_qsl(data))
 
         id = urlparse(self.entry.embed_url).query
         id = dict(parse_qsl(id))["id"]
-        enc_id = self.aes_encrypt(id, self.key).decode()
+        enc_id = self.aes_encrypt(id, enc_keys["key"], enc_keys["iv"]).decode()
         data.update(id=enc_id)
 
         headers = {
@@ -373,7 +371,11 @@ class videourl:
 
         response_err(r, r.url)
 
-        json_resp = json.loads(self.aes_decrypt(r.json().get("data"), self.second_key))
+        json_resp = json.loads(
+            self.aes_decrypt(
+                r.json().get("data"), enc_keys["second_key"], enc_keys["iv"]
+            )
+        )
 
         source_data = [x for x in json_resp["source"]]
         self.quality(source_data)
